# Year numbering

While TAU systems generally use the starting year of an academic year, such that 2024/2025 is set as 2024, TAU Tools use the ending year, i.e. 2025 for 2024/2025.
This means a translation of -1/+1 is required before/after switching to university systems accordingly.
